trunc: trunc

Description Usage Arguments Value Examples

Description

trunc

Usage

1
trunc(data, min_value)

Arguments

data

The input variable which will be altered if less than the threshold

min_value

the threshold which the input below it will be set to zero

Value

returns zero if the "data" is less than the "mean_value" otherwise returns the "data"

Examples

1
2
trunc(4,3)  # returns 4
trunc(2,3)  # returns 0

Javad-mun/activitycounts documentation built on June 6, 2019, 7:40 a.m.